@@ -39,7 +39,7 @@ class Exceptions:
 
 class CloudSearchDomainClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudsearchdomain/client.html)
     """
 
@@ -55,21 +55,21 @@ class CloudSearchDomainClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudsearchdomain/client.html#can_paginate)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudsearchdomain/client.html#generate_presigned_url)
         """
 
@@ -77,32 +77,32 @@ class CloudSearchDomainClient(BaseClient):
         self,
         *,
         query: str,
-        cursor: str = None,
-        expr: str = None,
-        facet: str = None,
-        filterQuery: str = None,
-        highlight: str = None,
-        partial: bool = None,
-        queryOptions: str = None,
-        queryParser: QueryParserType = None,
-        returnFields: str = None,
-        size: int = None,
-        sort: str = None,
-        start: int = None,
-        stats: str = None
+        cursor: str = ...,
+        expr: str = ...,
+        facet: str = ...,
+        filterQuery: str = ...,
+        highlight: str = ...,
+        partial: bool = ...,
+        queryOptions: str = ...,
+        queryParser: QueryParserType = ...,
+        returnFields: str = ...,
+        size: int = ...,
+        sort: str = ...,
+        start: int = ...,
+        stats: str = ...
     ) -> SearchResponseTypeDef:
         """
         Retrieves a list of documents that match the specified search criteria.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.search)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.search)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudsearchdomain/client.html#search)
         """
 
-    def suggest(self, *, query: str, suggester: str, size: int = None) -> SuggestResponseTypeDef:
+    def suggest(self, *, query: str, suggester: str, size: int = ...) -> SuggestResponseTypeDef:
         """
         Retrieves autocomplete suggestions for a partial query string.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.suggest)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.suggest)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudsearchdomain/client.html#suggest)
         """
 
@@ -112,6 +112,6 @@ class CloudSearchDomainClient(BaseClient):
         """
         Posts a batch of documents to a search domain for indexing.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.upload_documents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.upload_documents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudsearchdomain/client.html#upload_documents)
         """
