@@ -12,7 +12,11 @@ Usage::
     ```
 """
 import sys
-from typing import Dict, List
+from typing import IO, Any, Dict, List, Union
+
+from botocore.response import StreamingBody
+
+from .literals import ContentTypeType, QueryParserType
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -27,12 +31,16 @@ __all__ = (
     "FieldStatsTypeDef",
     "HitTypeDef",
     "HitsTypeDef",
+    "ResponseMetadataTypeDef",
+    "SearchRequestRequestTypeDef",
     "SearchResponseTypeDef",
     "SearchStatusTypeDef",
     "SuggestModelTypeDef",
+    "SuggestRequestRequestTypeDef",
     "SuggestResponseTypeDef",
     "SuggestStatusTypeDef",
     "SuggestionMatchTypeDef",
+    "UploadDocumentsRequestRequestTypeDef",
     "UploadDocumentsResponseTypeDef",
 )
 
@@ -98,6 +106,50 @@ HitsTypeDef = TypedDict(
     total=False,
 )
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
+_RequiredSearchRequestRequestTypeDef = TypedDict(
+    "_RequiredSearchRequestRequestTypeDef",
+    {
+        "query": str,
+    },
+)
+_OptionalSearchRequestRequestTypeDef = TypedDict(
+    "_OptionalSearchRequestRequestTypeDef",
+    {
+        "cursor": str,
+        "expr": str,
+        "facet": str,
+        "filterQuery": str,
+        "highlight": str,
+        "partial": bool,
+        "queryOptions": str,
+        "queryParser": QueryParserType,
+        "returnFields": str,
+        "size": int,
+        "sort": str,
+        "start": int,
+        "stats": str,
+    },
+    total=False,
+)
+
+
+class SearchRequestRequestTypeDef(
+    _RequiredSearchRequestRequestTypeDef, _OptionalSearchRequestRequestTypeDef
+):
+    pass
+
+
 SearchResponseTypeDef = TypedDict(
     "SearchResponseTypeDef",
     {
@@ -105,8 +157,8 @@ SearchResponseTypeDef = TypedDict(
         "hits": "HitsTypeDef",
         "facets": Dict[str, "BucketInfoTypeDef"],
         "stats": Dict[str, "FieldStatsTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 SearchStatusTypeDef = TypedDict(
@@ -128,13 +180,35 @@ SuggestModelTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredSuggestRequestRequestTypeDef = TypedDict(
+    "_RequiredSuggestRequestRequestTypeDef",
+    {
+        "query": str,
+        "suggester": str,
+    },
+)
+_OptionalSuggestRequestRequestTypeDef = TypedDict(
+    "_OptionalSuggestRequestRequestTypeDef",
+    {
+        "size": int,
+    },
+    total=False,
+)
+
+
+class SuggestRequestRequestTypeDef(
+    _RequiredSuggestRequestRequestTypeDef, _OptionalSuggestRequestRequestTypeDef
+):
+    pass
+
+
 SuggestResponseTypeDef = TypedDict(
     "SuggestResponseTypeDef",
     {
         "status": "SuggestStatusTypeDef",
         "suggest": "SuggestModelTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 SuggestStatusTypeDef = TypedDict(
@@ -156,6 +230,14 @@ SuggestionMatchTypeDef = TypedDict(
     total=False,
 )
 
+UploadDocumentsRequestRequestTypeDef = TypedDict(
+    "UploadDocumentsRequestRequestTypeDef",
+    {
+        "documents": Union[bytes, IO[bytes], StreamingBody],
+        "contentType": ContentTypeType,
+    },
+)
+
 UploadDocumentsResponseTypeDef = TypedDict(
     "UploadDocumentsResponseTypeDef",
     {
@@ -163,6 +245,6 @@ UploadDocumentsResponseTypeDef = TypedDict(
         "adds": int,
         "deletes": int,
         "warnings": List["DocumentServiceWarningTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
